@@ -3,27 +3,26 @@ import numpy as np
 from .individual import Individual
 from .evaluator import Evaluator
 from .optimizer import Optimizer
-from .logger import Logger, LOG_VERBOSE
+from .logging import logger, LOG_VERBOSE
 
 N = 10 # size of vector
 
 
 class RealVector(Individual):
 
-    def __init__(self, vec, logger=None):
-        super().__init__(logger)
+    def __init__(self, vec):
         self.vec = vec
 
     def __repr__(self):
         return str(self.vec) + " (loss={})".format(self.loss_)
 
     def copy(self):
-        ind = self.__class__(self.vec.copy(), self.logger_)
+        ind = self.__class__(self.vec.copy())
         return ind
 
     @classmethod
-    def random(cls, size, logger=None):
-        return cls(np.random.normal(loc=0, scale=2, size=N), logger=logger)
+    def random(cls, size):
+        return cls(np.random.normal(loc=0, scale=2, size=N))
 
     def mutate(self, mutation_rate=0.1, mutation_width=1):       
         if isinstance(mutation_width, int):
@@ -36,20 +35,19 @@ class RealVector(Individual):
         indices = np.random.choice(self.vec.size, size=k, replace=False)
         noise = np.random.normal(loc=0, scale=mutation_rate, size=k)
         self.vec[indices] += noise
-        self.log('Added ' + ', '.join(['{} to vec[{}]'.format(noise_, ix) for ix, noise_ in zip(indices, noise)]) + 'of #'+str(self.id_), log_level=2, id=12)
+        logger.log('Added ' + ', '.join(['{} to vec[{}]'.format(noise_, ix) for ix, noise_ in zip(indices, noise)]) + 'of #'+str(self.id_), level=2, id=12)
 
     def cross(self, other, crossover_rate=0.5):
         # uniform crossover
         k = max(1, np.random.binomial(self.vec.size, crossover_rate))
         indices = np.random.choice(self.vec.size, size=k, replace=False)
         self.vec[indices] = other.vec[indices]
-        self.log('#{} took indices {} from #{}'.format(self.id_, ', '.join(map(str,indices)), other.id_), log_level=2, id=13)
+        logger.log('#{} took indices {} from #{}'.format(self.id_, ', '.join(map(str,indices)), other.id_), level=2, id=13)
 
 
 class RealVectorEvaluator(Evaluator):
 
-    def __init__(self, target_vector, logger=None):
-        super().__init__(logger)
+    def __init__(self, target_vector):
         self.target_vec = target_vector
 
     def eval(self, ind):
@@ -63,6 +61,7 @@ def print_lines(ls):
 conf = {
     'parents': 5,
     'offspring': 10,
+    'selection': 'plus',
 
     'do_crossover': True,
     'do_self_adaption': True,
@@ -80,10 +79,11 @@ conf = {
 }
 
 
-with Logger(log_level=LOG_VERBOSE, file="main_log.txt") as l:
-    ev = RealVectorEvaluator(np.random.uniform(-20, 20, size=N), logger=l)
-    print('target: {}'.format(ev.target_vec))
-    opt = Optimizer(ev, config=conf, logger=l)
-    res = opt.run([RealVector.random(N, logger=l) for _ in range(5)], generations=50)
+logger.set_output('test_log.txt')
+logger.set_level(LOG_VERBOSE)
 
-#print_lines(res)
+ev = RealVectorEvaluator(np.random.uniform(-20, 20, size=N))
+print('target: {}'.format(ev.target_vec))
+opt = Optimizer(ev, config=conf)
+res = opt.run([RealVector.random(N) for _ in range(5)], generations=500)
+print_lines(res)
