@@ -7,15 +7,22 @@ default_config = {
     # enable/disable mutation and crossover
     'do_mutate': True,
     'do_crossover': False,
+    'do_self_adaption': True,
 
     # set mutation/crossover parameters
     'crossover_prob': 0.5,
     'mutation_prob': 1.0,
+    'learning_rate': 0.22, # for self-adaption
 
     # additional arguments
     'crossover_kwargs': {},
     'mutation_kwargs': {},
     
+    # parameter bounds (min, max) for self-adaption;
+    # only apply self-adaption when bounds are given
+    'crossover_kwargs_bounds': {},
+    'mutation_kwargs_bounds': {},
+
     'do_timeout_heuristic': False,
     'timeout': 100,
     'mutation_increment': 1.01,
